@@ -8,7 +8,7 @@ use Benchmark qw(timethese :hireswallclock);
 
 # Generate some data
 my ($pdl_data, $packed_data, $N);
-for my $log_n (1, 2, 3, 4, 5, 6) {
+for my $log_n (1, 2, 3, 4, 5, 6, 7) {
 	$N = 10**$log_n;
 	print "--- For N = $N ---\n";
 	
@@ -17,6 +17,8 @@ for my $log_n (1, 2, 3, 4, 5, 6) {
 	$packed_data = pack('d*', @data);
 	
 	timethese(1000, {  PDL => \&pdl_avg, CBlocks => \&c_blocks_avg});
+	print "PDL returned ", pdl_avg(), " and c_blocks_avg returned ",
+		c_blocks_avg(), "\n";
 }
 
 sub pdl_avg {
@@ -27,15 +29,15 @@ sub c_blocks_avg {
 	my $to_return;
 	cblock {
 		double accum = 0;
-		int i, N_data;
+		int i, N;
 		double * data;
 		
 		data = (double*)(SvPVbyte_nolen($packed_data));
-		N_data = SvIV($N);
-		for (i = 0; i < N_data; i++) {
+		N = SvIV($N);
+		for (i = 0; i < N; i++) {
 			accum += data[i];
 		}
-		sv_setnv($to_return, accum / N_data);
+		sv_setnv($to_return, accum / N);
 	}
 	return $to_return;
 }
