@@ -4,6 +4,7 @@
 
 use strict;
 use warnings;
+use warnings::register qw(import compiler linker);
 
 use Alien::TinyCCx;
 use XSLoader;
@@ -11,7 +12,7 @@ use XSLoader;
 # Use David Golden's version numbering suggestions. Note that we have to call
 # the XSLoader before evaling the version string because XS modules check the
 # version *string*, not the version *number*, at boot time.
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 XSLoader::load('C::Blocks', $VERSION);
 $VERSION = eval $VERSION;
 
@@ -33,6 +34,13 @@ sub import {
 	_import();
 }
 
+# Provided so I can call warnings::warnif from Blocks.xs. Why can't I
+# just call warnings::warnif from that code directly????  XXX
+sub warnif {
+	my ($category, $message) = @_;
+	warnings::warnif($category, $message);
+}
+
 # The XS code for the keyword parser makes sure that if a module invokes cshare,
 # it is also a descendent of C::Blocks::libloader. The only reason it does that
 # is to make sure that this function has a good chance of getting invoked when
@@ -435,47 +443,32 @@ from C<My::Module>.
 =head2 Breaking Sharing
 
 How do shared C declarations work? When C<C::Blocks> encounters a C<cshare>, it
-appends C<C::Blocks::libloader> to the current package's C<@ISA> array. The sole
-purpose of this is to provide a default C<import> method that properly copies
-the symbol table references in a lexically scoped way. This can be broken in one
-of two ways.
+injects a special C<import> method into the package that's being compiled. This
+C<import> method properly copies the symbol table references in a lexically
+scoped way so when some I<other> code C<use>s the pacage, the symbol tables are
+available for use in C<cblock>s, etc.
 
-First, if you overwrite C<@ISA> by direct assignment, you will erase the
-C<libloader> entry. This is easier than you might think. For example, this will
-break the import mechanism:
+If your module provides its own import method, or has package-scoped variables
+such as C<our $import>, C::Blocks will issue a warning and refrain from injecting
+the method.
 
- package Some::Code;
- our @ISA = qw(Base::Class);
- cshare {
-     /* ... */
- }
-
-The reason is that the assignment to C<@ISA> occurs when the package definition
-is executed, but C<libloader> is added to C<@ISA> at compile time (like adding
-it in a C<BEGIN> block).
-
-Another way to break sharing is to provide your own C<import> method which does
-not call C<C::Blocks::libloader::import>. In that case, Perl's own method
-resolution will resolve to your C<import> and never call C<libloader>'s. To fix
-this, you should include the following line in your C<import> method:
+If you module needs to provide its own import functionality, you can still get
+the code sharing with something like this:
 
+ no warnings 'C::Blocks::import';
  sub import {
-     my ($package, @args) = @_;
-     ...
-     C::Blocks::libloader::import($package);
+  ... your code here
+  C::Blocks::libloader::import(__PACKAGE__);
  }
 
-You could also experience this problem the other way around: you expect your
-module to use an inherited C<import> method, but you only get C<libloader>'s
-import behavior. You fix that by providing your own C<import> method:
+This will perform the requisite magic to make the code from your
+C<cshare> blocks visible to whichever packages C<use> your module, and
+avoid the warning.
 
- # NOTE: NEEDS TO BE TESTED
- sub import {
-     my ($package, @args) = @_;
-     C::Blocks::libloader::import($package);
-     my $method = Parent::Package->can('import');
-     goto &$method;
- }
+WARNING: At least for now, be sure to declare your C<import> method
+I<before> any C<cshare> blocks in your package. Declaring them after a
+C<cshare> block causes Perl to crash, probably because I'm not doing
+something right.
 
 =head2 XSUBs
 
@@ -590,6 +583,23 @@ should be the full library name, including file extensions. If the
 library is located in an unconventional location, the full path should
 be specified.
 
+=head2 Compiler and Linker Warnings
+
+Compiler warnings (such as C<assignment from incompatible pointer type>)
+and linker warnings (need example...) can be turned on and off using the
+L<warnings> pragma with categories C<C::Blocks::compiler> and
+C<C::Blocks::linker>. For example:
+
+ use warnings;  # compiler and linker warnings ON
+ ...
+ no warnings 'C::Blocks::compiler';  # compiler warnings OFF
+ ...
+ use warnings 'C::Blocks::compiler';  # back ON
+
+The warnings are handled using Perl's built-in warnings system, so as
+with all warnings, the reporting of compiler and linker warnings can be
+controlled lexically.
+
 =head1 KEYWORDS
 
 The way that C<C::Blocks> provides these functionalities is through lexically
